==> wicketstuff-restannotations-6.22.0-sources.jar: org/wicketstuff/rest/annotations/MethodMapping.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.wicketstuff.rest.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.wicketstuff.rest.contenthandling.RestMimeTypes;
import org.wicketstuff.rest.utils.http.HttpMethod;

/**
 * Annotation used to map a resource method to a given URL. The specified URL can contain parameter
 * segment (for example '{id}') and we can specify also the request method that must be used.
 * 
 * @author andrea del bene
 * @see HttpMethod
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface MethodMapping
{
	String value();

	HttpMethod httpMethod() default HttpMethod.GET;

	String consumes() default RestMimeTypes.APPLICATION_JSON;

	String produces() default RestMimeTypes.APPLICATION_JSON;
}

==> wicketstuff-restannotations-9.2.0-sources.jar: org/wicketstuff/rest/annotations/MethodMapping.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.wicketstuff.rest.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.wicketstuff.rest.contenthandling.mimetypes.RestMimeTypes;
import org.wicketstuff.restutils.http.HttpMethod;

/**
 * Annotation used to map a resource method to a given URL. The specified URL can contain parameter
 * segment (for example '{id}') and we can specify also the request method that must be used.
 *
 * @author andrea del bene
 * @see HttpMethod
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface MethodMapping
{
	String value();

	HttpMethod httpMethod() default HttpMethod.GET;

	String consumes() default RestMimeTypes.APPLICATION_JSON;

	String produces() default RestMimeTypes.APPLICATION_JSON;
}
